pub trait Constable: ConstableSeal { }Expand description
Marker that shows it can be used in const generic.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Constable: ConstableSeal { }Marker that shows it can be used in const generic.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".